unit CharConsts;

interface


uses
  classes,
  INIFileConsts;


const
  CHARSET_UPPERCASE       : string = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
  CHARSET_LOWERCASE       : string = 'abcdefghijklmnopqrstuvwxyz';
  CHARSET_NUMBERS         : string = '0123456789';
  CHAREST_DFLT_PUNCTUATION: string = DFLT_KEY_PUNCTUATION_SET;
  CHARSET_WHITESPACE      : string = ' ';


type
  TCharToSpoken = class
  private
    AllChars: TStringList;
  public
    constructor Create();
    destructor Destroy(); override;

    function GetSpokenChar(c: char): string;
  end;


implementation

uses
  dialogs,
  sysutils;


constructor TCharToSpoken.Create();
begin
  inherited;
  AllChars:= TStringList.Create();

  AllChars.Add('A=Upper case ''A'' (Alpha)');
  AllChars.Add('B=Upper case ''B'' (Bravo)');
  AllChars.Add('C=Upper case ''C'' (Charlie)');
  AllChars.Add('D=Upper case ''D'' (Delta)');
  AllChars.Add('E=Upper case ''E'' (Echo)');
  AllChars.Add('F=Upper case ''F'' (Foxtrot)');
  AllChars.Add('G=Upper case ''G'' (Golf)');
  AllChars.Add('H=Upper case ''H'' (Hotel)');
  AllChars.Add('I=Upper case ''I'' (India)');
  AllChars.Add('J=Upper case ''J'' (Juliet)');
  AllChars.Add('K=Upper case ''K'' (Kilo)');
  AllChars.Add('L=Upper case ''L'' (Lima)');
  AllChars.Add('M=Upper case ''M'' (Mike)');
  AllChars.Add('N=Upper case ''N'' (November)');
  AllChars.Add('O=Upper case ''O'' (Oscar)');
  AllChars.Add('P=Upper case ''P'' (Papa)');
  AllChars.Add('Q=Upper case ''Q'' (Quebec)');
  AllChars.Add('R=Upper case ''R'' (Romeo)');
  AllChars.Add('S=Upper case ''S'' (Sierra)');
  AllChars.Add('T=Upper case ''T'' (Tango)');
  AllChars.Add('U=Upper case ''U'' (Uniform)');
  AllChars.Add('V=Upper case ''V'' (Victor)');
  AllChars.Add('W=Upper case ''W'' (Whiskey)');
  AllChars.Add('X=Upper case ''X'' (X-Ray)');
  AllChars.Add('Y=Upper case ''Y'' (Yankee)');
  AllChars.Add('Z=Upper case ''Z'' (Zulu)');
  AllChars.Add('a=Lower case ''a'' (Alpha)');
  AllChars.Add('b=Lower case ''b'' (Bravo)');
  AllChars.Add('c=Lower case ''c'' (Charlie)');
  AllChars.Add('d=Lower case ''d'' (Delta)');
  AllChars.Add('e=Lower case ''e'' (Echo)');
  AllChars.Add('f=Lower case ''f'' (Foxtrot)');
  AllChars.Add('g=Lower case ''g'' (Golf)');
  AllChars.Add('h=Lower case ''h'' (Hotel)');
  AllChars.Add('i=Lower case ''i'' (India)');
  AllChars.Add('j=Lower case ''j'' (Juliet)');
  AllChars.Add('k=Lower case ''k'' (Kilo)');
  AllChars.Add('l=Lower case ''l'' (Lima)');
  AllChars.Add('m=Lower case ''m'' (Mike)');
  AllChars.Add('n=Lower case ''n'' (November)');
  AllChars.Add('o=Lower case ''o'' (Oscar)');
  AllChars.Add('p=Lower case ''p'' (Papa)');
  AllChars.Add('q=Lower case ''q'' (Quebec)');
  AllChars.Add('r=Lower case ''r'' (Romeo)');
  AllChars.Add('s=Lower case ''s'' (Sierra)');
  AllChars.Add('t=Lower case ''t'' (Tango)');
  AllChars.Add('u=Lower case ''u'' (Uniform)');
  AllChars.Add('v=Lower case ''v'' (Victor)');
  AllChars.Add('w=Lower case ''w'' (Whiskey)');
  AllChars.Add('x=Lower case ''x'' (X-Ray)');
  AllChars.Add('y=Lower case ''y'' (Yankee)');
  AllChars.Add('z=Lower case ''z'' (Zulu)');
  AllChars.Add('0=Zero');
  AllChars.Add('1=One');
  AllChars.Add('2=Two');
  AllChars.Add('3=Three');
  AllChars.Add('4=Four');
  AllChars.Add('5=Five');
  AllChars.Add('6=Six');
  AllChars.Add('7=Seven');
  AllChars.Add('8=Eight');
  AllChars.Add('9=Nine');
  AllChars.Add('@=At');
  AllChars.Add('[=Open square bracket');
  AllChars.Add('\=Backslash');
  AllChars.Add(']=Close square bracket');
  AllChars.Add('^=Caret');
  AllChars.Add('_=Underscore');
  AllChars.Add(' =Space');
  AllChars.Add('!=Exclamation mark');
  AllChars.Add('"=Double quote');
  AllChars.Add('#=Hash');
  AllChars.Add('$=Dollar');
  AllChars.Add('%=Percent');
  AllChars.Add('&=Ampersand');
  AllChars.Add('''=Single quote');
  AllChars.Add('(=Open bracket');
  AllChars.Add(')=Close bracket');
  AllChars.Add('*=Asterisk');
  AllChars.Add('+=Plus');
  AllChars.Add(',=Comma');
  AllChars.Add('-=Minus');
  AllChars.Add('.=Dot');
  AllChars.Add('/=Slash');
  AllChars.Add(':=Colon');
  AllChars.Add(';=Semi-colon');
  AllChars.Add('<=Less than');
  AllChars.Add('==Equals');
  AllChars.Add('>=Greater than');
  AllChars.Add('?=Question mark');
  AllChars.Add('`=Backtick');
  AllChars.Add('{=Open curly bracket');
  AllChars.Add('|=Bar');
  AllChars.Add('}=Close curly bracket');
  AllChars.Add('~=Tilde');

end;


destructor TCharToSpoken.Destroy();
var
  i: integer;
begin
  for i:=0 to (AllChars.count)-1 do
    begin
//    StrDispose(PChar(AllChars.Objects[i]));
    end;

  AllChars.Free();

  inherited;
end;


// Return the spoken version of the char supplied
function TCharToSpoken.GetSpokenChar(c: char): string;
var
  i: integer;
  spoken: string;
begin
  spoken := 'UNKNOWN CHARACTER';

  // We can't use IndexOfName of IndexOf because it's case INsensitive
  for i:=0 to (AllChars.count-1) do
    begin
    if pos(c, AllChars[i])=1 then
      begin
      spoken := AllChars[i];
      delete(spoken, 1, 2);
      break;
      end;
    end;

  Result := spoken;
end;


END.


