unit Options;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Menus, ComCtrls,
  INIFile, ExtCtrls;

type
  TfrmOptions = class(TForm)
    pbCancel: TButton;
    pbOK: TButton;
    pcOptions: TPageControl;
    tsCharsets: TTabSheet;
    GroupBox2: TGroupBox;
    Label1: TLabel;
    edPunctuationSet: TEdit;
    pbReset: TButton;
    GroupBox1: TGroupBox;
    ckUseUppercase: TCheckBox;
    ckUseLowercase: TCheckBox;
    ckUseNumbers: TCheckBox;
    ckUseSpace: TCheckBox;
    ckUsePunctuation: TCheckBox;
    GroupBox4: TGroupBox;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    rbMandatoryOneFromEachSelected: TRadioButton;
    rbMandatoryOneFromEachSelectedExceptSpace: TRadioButton;
    rbMandatoryNone: TRadioButton;
    tsVarious: TTabSheet;
    GroupBox3: TGroupBox;
    Label7: TLabel;
    ckCopyToClipboard: TCheckBox;
    ckNoStartEndInSpace: TCheckBox;
    rgRNGType: TRadioGroup;
    ckWarnClipboardCopy: TCheckBox;
    procedure pbResetClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure pbOKClick(Sender: TObject);
    procedure ckCopyToClipboardClick(Sender: TObject);
  private
    procedure EnableDisableControls();
  public
    INIFile: TPasswordGenIniFile;
  end;


implementation

{$R *.DFM}

uses
  CharConsts,
  SDUGeneral;


procedure TfrmOptions.pbResetClick(Sender: TObject);
begin
  edPunctuationSet.text := CHAREST_DFLT_PUNCTUATION;

end;

procedure TfrmOptions.FormCreate(Sender: TObject);
begin
  pcOptions.ActivePage := tsCharsets;
  
end;


procedure TfrmOptions.FormShow(Sender: TObject);
begin
  // TAB: Various
  // Options
  ckCopyToClipboard.checked   := INIFile.OptCopyPasswordsToClipboard;
  ckWarnClipboardCopy.checked := INIFile.OptWarnPasswordsCopiedToClipboard;
  ckNoStartEndInSpace.checked := INIFile.OptNoStartEndInSpace;


  // TAB: Character sets
  // Character sets available
  ckUseUppercase.checked   := INIFile.OptUseUppercase;
  ckUseLowercase.checked   := INIFile.OptUseLowercase;
  ckUseNumbers.checked     := INIFile.OptUseNumbers;
  ckUsePunctuation.checked := INIFile.OptUsePunctuation;
  ckUseSpace.checked       := INIFile.OptUseSpace;

  // Punctuation set
  edPunctuationSet.text := INIFile.OptPunctuationSet;

  // Character set usage
  rbMandatoryNone.checked := TRUE;
  rbMandatoryOneFromEachSelectedExceptSpace.checked := INIFile.OptForceCharFromEachSelectedCharSetExceptSpace;
  rbMandatoryOneFromEachSelected.checked            := INIFile.OptForceCharFromEachSelectedCharSet;

  // RNG
  rgRNGType.ItemIndex := ord(INIFile.OptRNGType);

  EnableDisableControls();

end;

procedure TfrmOptions.pbOKClick(Sender: TObject);
begin
  // TAB: Various
  // Options
  INIFile.OptCopyPasswordsToClipboard       := ckCopyToClipboard.checked;
  INIFile.OptWarnPasswordsCopiedToClipboard := ckWarnClipboardCopy.checked;
  INIFile.OptNoStartEndInSpace              := ckNoStartEndInSpace.checked;


  // TAB: Character sets
  // Character sets available
  INIFile.OptUseUppercase   := ckUseUppercase.checked;
  INIFile.OptUseLowercase   := ckUseLowercase.checked;
  INIFile.OptUseNumbers     := ckUseNumbers.checked;
  INIFile.OptUsePunctuation := ckUsePunctuation.checked;
  INIFile.OptUseSpace       := ckUseSpace.checked;

  // Punctuation set
  INIFile.OptPunctuationSet := edPunctuationSet.text;

  // Character set usage
  INIFile.OptForceCharFromEachSelectedCharSetExceptSpace := rbMandatoryOneFromEachSelectedExceptSpace.checked;
  INIFile.OptForceCharFromEachSelectedCharSet := rbMandatoryOneFromEachSelected.checked;

  // RNG
  INIFile.OptRNGType := TRNGType(rgRNGType.ItemIndex);


  ModalResult := mrOK;

end;


procedure TfrmOptions.EnableDisableControls();
begin
  ckWarnClipboardCopy.enabled := ckCopyToClipboard.checked;

end;


procedure TfrmOptions.ckCopyToClipboardClick(Sender: TObject);
begin
  EnableDisableControls();

end;

END.


